OC.L10N.register(
    "mail",
    {
    "Personal" : "Udmawan",
    "Mail" : "Tirawt",
    "Save" : "Sekles",
    "Connect" : "Qqen",
    "Name" : "Nom",
    "Password" : "Awal uffir",
    "None" : "Ula d yiwen",
    "Go back" : "Tuɣalin",
    "Email address" : "Tansa imayl",
    "Cancel" : "Sefsex",
    "General" : "Amatu",
    "Appearance" : "Udem",
    "List" : "Tabdart",
    "Newest first" : "Imaynuten d imezwura",
    "Oldest first" : "Iqbuṛen d imezwura",
    "Privacy" : "Vie privée",
    "Delete" : "Kkes",
    "Search" : "Nadi",
    "Send" : "Tuzna",
    "Refresh" : "Sismeḍ",
    "About" : "Γef",
    "Ok" : "Ih",
    "Choose" : "Fren",
    "Confirm" : "Serggeg",
    "Favorite" : "Menyif",
    "Read" : "Taɣuri",
    "More actions" : "Ugar n tigawin",
    "Back" : "Retour",
    "Mark as unread" : "Creḍ ur yettwaɣra ara",
    "Mark as read" : "Creḍ yettwaɣra",
    "Description" : "Aglam",
    "Create" : "Snulfu-d",
    "Select" : "Fren",
    "Comment" : "Commentaire",
    "Remove" : "Kkes",
    "Today" : "Ass-a",
    "Yesterday" : "Iḍelli",
    "Choose target folder" : "Fren akaram aniccan",
    "Favorites" : "Imenyafen",
    "Other" : "Wayeḍ",
    "Forward" : "Avancer",
    "Translate" : "Suqel",
    "Move" : "Senkez",
    "Remove account" : "Kkes amiḍan",
    "Add folder" : "Rnu akaram",
    "Folder name" : "Isem n ukaram",
    "Delete folder" : "Kkes akaram",
    "Rename" : "Beddel isem",
    "Draft" : "Arewway",
    "Reply" : "Err",
    "Retry" : "Ɛreḍ tikkelt-nniḍen",
    "Message" : "Izen",
    "Copy to clipboard" : "Nɣel-it ar tecfawit",
    "Add" : "Rnu",
    "Clear" : "Ṣfeḍ",
    "Close" : "Mdel",
    "Date" : "Azemz",
    "Tags" : "Tibzimin",
    "Task created" : "Tawuri tettwarna",
    "Not found" : "Ulac-it",
    "To:" : "Ɣer:",
    "Translate from" : "Suqel seg",
    "Translate to" : "Suqel ar",
    "Deleted" : "Yettwakkes",
    "Help" : "Tallalt",
    "Actions" : "Tigawin",
    "Edit" : "Ẓreg",
    "User" : "Aseqdac",
    "Guest" : "Inebgi",
    "Group" : "Agraw",
    "Shared" : "Yettwabḍa",
    "Account connected" : "Amiḍan d uqqin",
    "All" : "Akk",
    "Inbox" : "Tanaka",
    "Nextcloud Mail" : "Imayl n Nextcloud",
    "Message sent" : "Izen yettwazen",
    "Last 7 days" : "7 n wussan yezrin"
},
"nplurals=2; plural=(n != 1);");
