OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "內嵌郵件 %s",
    "Important mail" : "重要郵件",
    "No message found yet" : "找不到訊息",
    "Set up an account" : "設定帳號",
    "Unread mail" : "未讀郵件",
    "Important" : "重要",
    "Work" : "工作",
    "Personal" : "個人",
    "To Do" : "待辦",
    "Later" : "稍後",
    "Mail" : "電子郵件",
    "You are reaching your mailbox quota limit for {account_email}" : "您即將達到 {account_email} 的信箱配額限制",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "您目前使用了信箱儲存空間的 {percentage}。請刪除不必要的電子郵件以釋出空間。",
    "Mail Application" : "郵件應用程式",
    "Mails" : "郵件",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "寄件者電子郵件：%1$s 不在通訊錄中，但寄件者名稱：%2$s 在通訊錄中，但其電子郵件為：%3$s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "寄件者電子郵件：%1$s 不在通訊錄中，但寄件者名稱：%2$s 在通訊錄中，但其電子郵件為：%3$s",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "寄件者使用了自訂的電子郵件：%1$s 而非寄件者的電子郵件：%2$s",
    "Sent date is in the future" : "寄件日期是未來的日期",
    "Mail server marked this message as phishing attempt" : "郵件伺服器將此訊息標記為網路釣魚企圖",
    "Some addresses in this message are not matching the link text" : "此訊息中的某些地址與連結文字不相符",
    "Reply-To email: %1$s is different from sender email: %2$s" : "Reply-To 電子郵件：%1$s 與寄件者的電子郵件地址 %2$s 不同",
    "Mail connection performance" : "郵件連線效能",
    "Slow mail service detected (%1$s) an attempt to connect to several accounts took an average of %2$s seconds per account" : "偵測到緩慢的郵件服務 (%1$s) 嘗試連線到數個帳號時，每個帳號平均費時%2$s秒",
    "Slow mail service detected (%1$s) an attempt to perform a mail box list operation on several accounts took an average of %2$s seconds per account" : "偵測到緩慢的郵件服務 (%1$s) 嘗試在數個帳號執行信箱清單動作時，每個帳號平均費時%2$s秒",
    "Mail Transport configuration" : "郵件傳輸組態",
    "The app.mail.transport setting is not set to smtp. This configuration can cause issues with modern email security measures such as SPF and DKIM because emails are sent directly from the web server, which is often not properly configured for this purpose. To address this, we have discontinued support for the mail transport. Please remove app.mail.transport from your configuration to use the SMTP transport and hide this message. A properly configured SMTP setup is required to ensure email delivery." : "app.mail.transport 設定未設定為 smtp。此設定可能會造成 SPF 與 DKIM 等現代電子郵件安全措施的問題，因為電子郵件是直接從網頁伺服器傳送，而網頁伺服器通常並未針對此目的進行適當的設定。為解決這個問題，我們已停止對郵件傳輸的支援。請從您的設定中移除 app.mail.transport，以使用 SMTP 傳輸並隱藏此訊息。需要正確設定 SMTP 設定，以確保電子郵件傳送。",
    "Mail account parameters, aliases and preferences" : "郵件帳號參數、別名與偏好設定",
    "💌 A mail app for Nextcloud" : "Nextcloud 的郵件應用程式",
    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](https://www.horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!\n\n## Ethical AI Rating\n\n### Priority Inbox\n\nPositive:\n* The software for training and inferencing of this model is open source.\n* The model is created and trained on-premises based on the user's own data.\n* The training data is accessible to the user, making it possible to check or correct for bias or optimise the performance and CO2 usage.\n\n### Thread Summaries (opt-in)\n\n**Rating:** 🟢/🟡/🟠/🔴\n\nThe rating depends on the installed text processing backend. See [the rating overview](https://docs.nextcloud.com/server/latest/admin_manual/ai/index.html) for details.\n\nLearn more about the Nextcloud Ethical AI Rating [in our blog](https://nextcloud.com/blog/nextcloud-ethical-ai-rating/)." : "**💌 Nextcloud 的郵件應用程式**\n\n- **🚀 與其他 Nextcloud 應用程式整合！**目前有通訊錄、日曆與檔案，還有更多即將到來的應用程式整合。\n- **📥 多重郵件帳號！**私人與公司帳號？沒問題，還有一個很好的統一收件匣。連線到任何 IMAP 帳號。\n- **🔒 傳送與接收加密郵件！**使用超棒的 [Mailvelope](https://mailvelope.com) 瀏覽器擴充套件。\n- **🙈 我們並未重新發明輪子！**而是以超棒的 [Horde](https://www.horde.org) 函式庫為基礎開發。\n- **📬 想要架設您自己的郵件伺服器嗎？**我們不必重新實做它，因為您可以架設 [Mail-in-a-Box](https://mailinabox.email)！\n\n## 道德人工智慧評分\n\n### 優先收件匣\n\n正面：\n* 該模型的訓練與推理軟體是開放原始碼的。\n* 該模型是根據使用者自己的資料在本機建立與訓練的。\n* 使用者可以存取訓練資料，因而可以檢查、糾正偏差或最佳化效能與二氧化碳的排放量。\n\n### 郵件串摘要（選擇性加入）\n\n**評分：** 🟢/🟡/🟠/🔴\n\n評分取決於安裝的文字處理後端。請見[評分概覽](https://docs.nextcloud.com/server/latest/admin_manual/ai/index.html)以取得更多資訊。\n\n[在我們的部落格](https://nextcloud.com/blog/nextcloud-ethical-ai-rating/)取得更多關於 Nextcloud 道德人工智慧評分的資訊。",
    "Your session has expired. The page will be reloaded." : "您的工作階段已過期。頁面將會重新載入。",
    "Drafts are saved in:" : "草稿儲存於：",
    "Sent messages are saved in:" : "已傳送的郵件儲存於：",
    "Deleted messages are moved in:" : "已刪除的郵件移動至：",
    "Archived messages are moved in:" : "封存的訊息被移動至：",
    "Snoozed messages are moved in:" : "延後的郵件會移入：",
    "Junk messages are saved in:" : "垃圾郵件儲存於：",
    "Connecting" : "正在連線",
    "Reconnect Google account" : "重新連結 Google 帳號",
    "Sign in with Google" : "使用 Google 登入",
    "Reconnect Microsoft account" : "重新連結 Microsoft 帳號",
    "Sign in with Microsoft" : "使用 Microsoft 登入",
    "Save" : "儲存",
    "Connect" : "連線",
    "Looking up configuration" : "正在查詢設定",
    "Checking mail host connectivity" : "正在檢查郵件主機連線能力",
    "Configuration discovery failed. Please use the manual settings" : "設定探索失敗。請使用手動設定",
    "Password required" : "請輸入密碼",
    "Testing authentication" : "正在測試驗證",
    "Awaiting user consent" : "等待使用者同意",
    "Account created. Please follow the pop-up instructions to link your Google account" : "帳號已建立。請按照彈出的說明連結您的 Google 帳號",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "帳號已建立。請按照彈出的說明連結您的 Microsoft 帳號",
    "Loading account" : "正在載入帳號",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "帳號已更新。請按照彈出的說明重新連結您的 Google 帳號",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "帳號已更新。請按照彈出的說明重新連結您的 Microsoft 帳號",
    "Account updated" : "已更新帳號",
    "IMAP server is not reachable" : "IMAP 伺服器無法連線",
    "SMTP server is not reachable" : "SMTP 伺服器無法連線",
    "IMAP username or password is wrong" : "IMAP 使用者名稱或密碼錯誤",
    "SMTP username or password is wrong" : "SMTP 使用者名稱或密碼錯誤",
    "IMAP server denied authentication" : "IMAP 伺服器拒絕驗證",
    "SMTP server denied authentication" : "SMTP 伺服器拒絕驗證",
    "IMAP authentication error" : "IMAP 驗證錯誤",
    "SMTP authentication error" : "SMTP 驗證錯誤",
    "IMAP connection failed" : "IMAP 連線失敗",
    "SMTP connection failed" : "SMTP 連線失敗",
    "Authorization pop-up closed" : "已關閉授權彈出式視窗",
    "Configuration discovery temporarily not available. Please try again later." : "設定探索暫時無法使用。請稍後再試。",
    "There was an error while setting up your account" : "設定您的帳號時發生錯誤",
    "Auto" : "自動",
    "Name" : "名字",
    "Mail address" : "電子郵件地址",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "請輸入格式為 name@example.com 的電子郵件地址",
    "Password" : "密碼",
    "Enable mark as important classification" : "啟用標記為重要分類",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP 設定",
    "IMAP Host" : "IMAP 主機",
    "IMAP Security" : "IMAP 安全性",
    "None" : "無",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 連接埠",
    "IMAP User" : "IMAP 帳號",
    "IMAP Password" : "IMAP 密碼",
    "SMTP Settings" : "SMTP 設定",
    "SMTP Host" : "SMTP 主機",
    "SMTP Security" : "SMTP 安全性",
    "SMTP Port" : "SMTP 連接埠",
    "SMTP User" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "要讓 Google 帳號與此應用程式搭配使用，您必須為 Google 帳號啟用雙重驗證並產生應用程式密碼。",
    "Account settings" : "帳號設定",
    "Aliases" : "別名",
    "Alias to S/MIME certificate mapping" : "別名至 S/MIME 憑證對映",
    "Signature" : "簽章",
    "A signature is added to the text of new messages and replies." : "對新信件與回覆信件內容已新增一個簽名檔",
    "Writing mode" : "寫作模式",
    "Preferred writing mode for new messages and replies." : "新郵件與回覆偏好的寫作模式。",
    "Default folders" : "預設資料夾",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "用於存放草稿、寄件備份、已刪除郵件、封存郵件與垃圾郵件的資料夾。",
    "Automatic trash deletion" : "自動垃圾桶刪除",
    "Days after which messages in Trash will automatically be deleted:" : "垃圾桶的郵件將會自動刪除的天數：",
    "Autoresponder" : "自動回覆程式",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "自動回覆收到的訊息。若某人向您傳送多則訊息，此自動回覆將會最多每四天傳送一次。",
    "The autoresponder uses Sieve, a scripting language supported by many email providers. If you're unsure whether yours does, check with your provider. If Sieve is available, click the button to go to the settings and enable it." : "自動回覆使用 Sieve，這是一種許多電子郵件供應商都支援的命令稿語言。如果您不確定您的供應商是否支援，請向供應商查詢。如果 Sieve 可用，請按一下按鈕前往設定並啟用它。",
    "Go to Sieve settings" : "前往 Sieve 設定",
    "Calendar settings" : "行事曆設定",
    "Classification settings" : "分類設定",
    "Filters" : "過濾",
    "Quick actions" : "快速動作",
    "Sieve script editor" : "Sieve 命令稿編輯器",
    "Mail server" : "郵件伺服器",
    "Sieve server" : "Sieve 伺服器",
    "Folder search" : "資料夾搜尋",
    "Update alias" : "更新别名",
    "Rename alias" : "重新命名別名",
    "Show update alias form" : "顯示更新別名表格",
    "Delete alias" : "删除别名",
    "Go back" : "返回",
    "Change name" : "更改名稱",
    "Email address" : "電子郵件地址",
    "Add alias" : "新增別名",
    "Create alias" : "建立別名",
    "Cancel" : "取消",
    "Search the body of messages in priority Inbox" : "在優先收件匣中搜尋郵件內文",
    "Activate" : "啟用",
    "Make mails available to Context Chat" : "讓郵件可用於情境聊天",
    "Remind about messages that require a reply but received none" : "提醒待回覆但尚未收到回應的訊息",
    "Highlight external addresses" : "突顯外部地址",
    "Could not update preference" : "無法更新偏好設定",
    "Mail settings" : "電子郵件設定",
    "General" : "一般",
    "Set as default mail app" : "設定為預設的郵件應用程式",
    "Add mail account" : "新增郵件帳號",
    "Appearance" : "外觀",
    "Show all messages in thread" : "在討論串中顯示所有訊息",
    "When off, only the selected message will be shown" : "關閉時，僅顯示選定的郵件",
    "Sort favorites up" : "將最愛排序至頂端",
    "When on, favorite messages will be sorted to the top of folders" : "啟用後，最愛訊息將排序至資料夾頂端",
    "Layout" : "佈局",
    "Vertical split" : "垂直分割",
    "Horizontal split" : "水平分割",
    "List" : "清單",
    "Use compact mode" : "使用簡潔模式",
    "Sorting" : "排序",
    "Newest first" : "新的在前",
    "Oldest first" : "舊的在前",
    "Avatars from Gravatar and favicons" : "來自 Gravatar 與 favicon 的大頭照",
    "Reply position" : "回覆位置",
    "Top" : "頂部",
    "Bottom" : "底部",
    "Text blocks" : "文字區塊",
    "Reusable pieces of text that can be inserted in messages" : "可重複使用的文字片段，可用於插入郵件中",
    "New text block" : "新文字區塊",
    "Shared with me" : "與我分享",
    "Privacy" : "隱私",
    "Data collection" : "資料蒐集",
    "Allow the app to collect and process data locally to adapt to your preferences" : "允許應用程式在本機蒐集並處理資料，以適應您的偏好設定",
    "Always show images from" : "一律顯示圖片，來自",
    "Security" : "安全性",
    "Manage your internal addresses and domains to ensure recognized contacts stay unmarked" : "管理您的內部位址與域名，以確保已辨識的聯絡人不受標記",
    "S/MIME" : "S/MIME",
    "Manage certificates" : "管理憑證",
    "Mailvelope" : "Mailvelope",
    "Mailvelope is enabled for the current domain." : "Mailvelope 已於目前網域啟用。",
    "Step 1" : "第 1 步",
    "Install the browser extension" : "安裝瀏覽器擴充套件",
    "Step 2" : "第 2 步",
    "Enable for the current domain" : "為目前網域啟用",
    "Assistance features" : "協助功能",
    "Context Chat integration" : "情境聊天整合",
    "Compose new message" : "撰寫新信件",
    "Newer message" : "較新的信件",
    "Older message" : "較舊的信件",
    "Toggle star" : "加上／移除星號",
    "Toggle unread" : "標示未讀／已讀",
    "Archive" : "封存",
    "Delete" : "刪除",
    "Search" : "搜尋",
    "Send" : "傳送",
    "Refresh" : "重新整理",
    "About" : "關於",
    "Acknowledgements" : "致謝",
    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "此應用程式包含 CKEditor，這是開放原始碼的編輯器。Copyright © CKEditor 貢獻者。以 GPLv2 授權。",
    "Title of the text block" : "文字區塊標題",
    "Content of the text block" : "文字區塊內容",
    "Ok" : "確定",
    "Automatically create tentative appointments in calendar" : "自動在行事曆中建立暫定預約",
    "No certificate" : "無憑證",
    "Certificate updated" : "憑證已更新",
    "Could not update certificate" : "無法更新憑證",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - 有效期限至 {expiryDate}",
    "Select an alias" : "選取別名",
    "Select certificates" : "選取憑證",
    "Update Certificate" : "更新憑證",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "伺服器不信任所選的憑證。收件人可能無法驗證您的簽名。",
    "Encrypt with S/MIME and send later" : "使用 S/MIME 加密並稍後傳送",
    "Encrypt with S/MIME and send" : "使用 S/MIME 加密並傳送",
    "Encrypt with Mailvelope and send later" : "使用 Mailvelope 加密並稍後傳送",
    "Encrypt with Mailvelope and send" : "使用 Mailvelope 加密並傳送",
    "Send later" : "稍後傳送",
    "Message {id} could not be found" : "找不到郵件 {id}",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "已選取使用 S/MIME 簽署或加密，但選定的別名沒有憑證。此訊息將不會被簽署或加密。",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "任何現有格式（例如粗體、義式斜體、底線或內嵌圖片）都將被移除。",
    "Turn off formatting" : "關閉格式化",
    "Turn off and remove formatting" : "關閉並移除格式化",
    "Keep formatting" : "保留格式化",
    "From" : "從",
    "Select account" : "選取帳號",
    "To" : "至",
    "Cc/Bcc" : "副本/密件副本",
    "Select recipient" : "選取收件者",
    "Contact or email address …" : "聯絡人或電子郵件地址……",
    "Cc" : "副本",
    "Bcc" : "密件副本",
    "Subject" : "主旨",
    "Subject …" : "主旨……",
    "This message came from a noreply address so your reply will probably not be read." : "此郵件來自 noreply 地址，所以您的回覆可能不會被閱讀。",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "以下收件者沒有 S/MIME 憑證：{recipients}。",
    "The following recipients do not have a PGP key: {recipients}." : "以下收件者沒有 PGP 金鑰：{recipients}。",
    "Write message …" : "編寫訊息……",
    "Saving draft …" : "正在儲存草稿……",
    "Error saving draft" : "儲存草稿時發生錯誤",
    "Draft saved" : "草稿已儲存",
    "Save draft" : "儲存草稿",
    "Discard & close draft" : "放棄並關閉草稿",
    "Enable formatting" : "啟用格式",
    "Disable formatting" : "停用格式化",
    "Upload attachment" : "已上傳附件",
    "Add attachment from Files" : "從雲端檔案中加入附件",
    "Add share link from Files" : "新增來自檔案的分享連結",
    "Smart picker" : "智慧型挑選器",
    "Request a read receipt" : "索取讀取回條",
    "Sign message with S/MIME" : "使用 S/MIME 簽署訊息",
    "Encrypt message with S/MIME" : "使用 S/MIME 加密訊息",
    "Encrypt message with Mailvelope" : "使用 Mailvelope 加密郵件",
    "Send now" : "立刻傳送",
    "Tomorrow morning" : "明天早上",
    "Tomorrow afternoon" : "明天下午",
    "Monday morning" : "週一早上",
    "Custom date and time" : "自訂日期與時間",
    "Enter a date" : "輸入日期",
    "Choose" : "選擇",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["附件超過了允許的附件大小 {size}。請透過連結分享檔案。"],
    "Choose a file to add as attachment" : "選擇要作為附件的檔案",
    "Choose a file to share as a link" : "選擇要作為連結分享的檔案",
    "_{count} attachment_::_{count} attachments_" : ["{count} 個附件"],
    "Untitled message" : "未命名訊息",
    "Expand composer" : "展開編輯器",
    "Close composer" : "關閉編輯器",
    "Confirm" : "確認",
    "Tag: {name} deleted" : "標籤：{name} 已刪除",
    "An error occurred, unable to delete the tag." : "遇到錯誤，無法刪除標籤。",
    "The tag will be deleted from all messages." : "該標籤將從所有訊息刪除。",
    "Plain text" : "純文字",
    "Rich text" : "RTF",
    "No messages in this folder" : "此收件匣中沒有信件",
    "No messages" : "沒有郵件",
    "Blind copy recipients only" : "僅密件副本收件者",
    "No subject" : "沒有主旨",
    "{markup-start}Draft:{markup-end} {subject}" : "{markup-start}草稿：{markup-end} {subject}",
    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
    "Set reminder for later today" : "設定今天稍後的提醒",
    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
    "Set reminder for tomorrow" : "設定明天的提醒",
    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
    "Set reminder for this weekend" : "設定本週末的提醒",
    "Next week – {timeLocale}" : "下週 – {timeLocale}",
    "Set reminder for next week" : "設定下週的提醒",
    "Could not apply tag, configured tag not found" : "無法套用標籤，找不到設定的標籤",
    "Could not move thread, destination mailbox not found" : "無法移動討論串，找不到目標信箱",
    "Could not execute quick action" : "無法執行快速動作",
    "Quick action executed" : "已執行快速動作",
    "No trash folder configured" : "未設定垃圾桶資料夾",
    "Could not delete message" : "無法刪除郵件",
    "Could not archive message" : "無法封存訊息",
    "Thread was snoozed" : "討論串已延後",
    "Could not snooze thread" : "無法延後討論串",
    "Thread was unsnoozed" : "討論已取消延後",
    "Could not unsnooze thread" : "無法取消延後討論串",
    "This summary was AI generated" : "此摘要為人工智慧產生",
    "Encrypted message" : "加密訊息",
    "This message is unread" : "此訊息未讀",
    "Unfavorite" : "取消收藏",
    "Favorite" : "收藏",
    "Unread" : "未讀",
    "Read" : "已讀",
    "Unimportant" : "不重要",
    "Mark not spam" : "標記為非垃圾郵件",
    "Mark as spam" : "標記為垃圾郵件",
    "Edit tags" : "編輯標籤",
    "Snooze" : "延後",
    "Unsnooze" : "取消延後",
    "Move thread" : "移動討論串",
    "Move Message" : "移動訊息",
    "Archive thread" : "封存討論串",
    "Archive message" : "封存訊息",
    "Delete thread" : "刪除討論串",
    "Delete message" : "刪除訊息",
    "More actions" : "更多動作",
    "Back" : "返回",
    "Set custom snooze" : "設定自訂延後",
    "Edit as new message" : "以新郵件的方式編輯",
    "Reply with meeting" : "使用會議回覆",
    "Create task" : "建立工作項目",
    "Download message" : "下載訊息",
    "Back to all actions" : "回到所有動作",
    "Manage quick actions" : "管理快速動作",
    "Load more" : "載入更多",
    "_Mark {number} read_::_Mark {number} read_" : ["將 {number} 標記為已讀"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["將 {number} 標記為未讀"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["將 {number} 標記為重要"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["將 {number} 標記為不重要"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["取消我的最愛 {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["我的最愛 {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["取消選取 {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["將 {number} 標記為垃圾郵件"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["將 {number} 標記為並非垃圾郵件"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["為 {number} 個編輯標籤"],
    "_Move {number} thread_::_Move {number} threads_" : ["移動 {number} 個討論串"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["轉寄 {number} 作為附件"],
    "Mark as unread" : "標為未讀",
    "Mark as read" : "標為已讀",
    "Mark as unimportant" : "標記為不重要",
    "Mark as important" : "標記為重要",
    "Report this bug" : "回報此臭蟲",
    "Event created" : "已建立事件",
    "Could not create event" : "無法建立活動",
    "Create event" : "建立事件",
    "All day" : "全天",
    "Attendees" : "參與者",
    "You can only invite attendees if your account has an email address set" : "您僅能在您的帳號設定了電子郵件地址的情況下邀請參與者",
    "Select calendar" : "選取日曆",
    "Description" : "描述",
    "Create" : "建立",
    "This event was updated" : "此活動已更新",
    "{attendeeName} accepted your invitation" : "{attendeeName} 已接受您的邀請",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} 暫時接受了您的邀請",
    "{attendeeName} declined your invitation" : "{attendeeName} 已拒絕您的邀請",
    "{attendeeName} reacted to your invitation" : "{attendeeName} 已對您的邀請作出回應",
    "Failed to save your participation status" : "儲存您的參與狀態失敗",
    "You accepted this invitation" : "您接受了此邀请",
    "You tentatively accepted this invitation" : "您暫時接受了此邀請",
    "You declined this invitation" : "您拒絕了此邀請",
    "You already reacted to this invitation" : "您已對此邀請作出回應",
    "You have been invited to an event" : "您已受邀參加活動",
    "This event was cancelled" : "此活動已取消",
    "Save to" : "儲存為",
    "Select" : "選取",
    "Comment" : "留言",
    "Accept" : "接受",
    "Decline" : "回絕",
    "Tentatively accept" : "暫時接受",
    "More options" : "更多選項",
    "This message has an attached invitation but the invitation dates are in the past" : "此訊息包含邀請，但邀請日期已過",
    "This message has an attached invitation but the invitation does not contain a participant that matches any configured mail account address" : "此訊息包含邀請，但邀請中不包含與任何設定的電子郵件地址相符的參與者",
    "Could not remove internal address {sender}" : "無法移除內部地址 {sender}",
    "Could not add internal address {address}" : "無法新增內部地址 {address}",
    "individual" : "個人",
    "domain" : "網域",
    "Remove" : "移除",
    "Add internal address" : "新增內部地址",
    "Add internal email or domain" : "新增內部電子郵件或網域",
    "Itinerary for {type} is not supported yet" : "目前尚未支援 {type} 的行程",
    "To archive a message please configure an archive folder in account settings" : "要封存訊息，請在帳號設定中設定封存資料夾。",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "您不能將此訊息移到封存資料夾及/或從目前資料夾中刪除此訊息",
    "Your IMAP server does not support storing the seen/unseen state." : "您的 IMAP 伺服器不支援已讀/未讀狀態。",
    "Could not mark message as seen/unseen" : "無法將郵件標記為已讀/未讀",
    "Last hour" : "上個小時",
    "Today" : "今天",
    "Yesterday" : "昨日",
    "Last week" : "上星期",
    "Last month" : "上個月",
    "Could not open folder" : "無法開啟資料夾",
    "Loading messages …" : "正在載入訊息……",
    "Indexing your messages. This can take a bit longer for larger folders." : "正在索引您的郵件。對於較大的資料夾來說，這可能需要較長的時間。",
    "Choose target folder" : "選擇目標資料夾",
    "No more submailboxes in here" : "這裡沒有更多子信箱",
    "Messages will automatically be marked as important using AI. The system learns from which messages you interact with or mark as important. In the beginning you might have to manually change the importance to teach it, but it will improve over time" : "系統將運用人工智慧自動標記重要訊息。系統會學習您互動或標記為重要的訊息類型。初期您可能需要手動調整重要性設定來訓練系統，但其判斷能力將隨時間逐步提升。",
    "Messages that you marked as favorite will be shown at the top of folders. You can disable this behavior in the app settings" : "您標記為最愛的訊息將顯示於資料夾頂端。您可在應用程式設定中停用此功能。",
    "AI identifies messages sent by you that likely require a reply but did not receive one after a couple of days and shows them here" : "人工智慧會辨識您發送的訊息中，那些很可能需要回覆卻在數日後仍未獲回應的內容，並將其顯示於此處。",
    "Favorites" : "我的最愛",
    "Favorites info" : "最愛資訊",
    "Load more favorites" : "載入更多最愛",
    "Follow up" : "跟進",
    "Follow up info" : "跟進訊息",
    "Load more follow ups" : "載入更多後續內容",
    "Important info" : "重要資訊",
    "Load more important messages" : "載入更多重要訊息",
    "Other" : "其他",
    "Load more other messages" : "載入更多其他訊息",
    "Could not send mdn" : "無法傳送 mdn",
    "The sender of this message has asked to be notified when you read this message." : "當您閱讀此郵件時，此郵件的寄件者要求通知。",
    "Notify the sender" : "通知寄件者",
    "You sent a read confirmation to the sender of this message." : "你已將讀取回條傳送給此郵件的寄件者。",
    "Message was snoozed" : "郵件已延後",
    "Could not snooze message" : "無法延後郵件",
    "Message was unsnoozed" : "訊息已取消延後",
    "Could not unsnooze message" : "無法取消延後訊息",
    "Forward" : "轉寄",
    "Move message" : "移動訊息",
    "Translate" : "翻譯",
    "Forward message as attachment" : "將郵件作為附件轉發",
    "View source" : "檢視原始碼",
    "Print message" : "列印訊息",
    "Create mail filter" : "建立郵件篩選器",
    "Download thread data for debugging" : "下載郵件串的資料以供除錯",
    "Suggested replies are using AI" : "建議的回覆是使用人工智慧產生的",
    "Message body" : "郵件正文",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "警告：此郵件的 S/MIME 簽章未經驗證。寄件人可能在冒充某人！",
    "AI info" : "人工智慧資訊",
    "Unnamed" : "未命名",
    "Embedded message" : "內嵌郵件",
    "Attachment saved to Files" : "附件已儲存至檔案",
    "Attachment could not be saved" : "無法儲存附件",
    "calendar imported" : "已匯入行事曆",
    "Choose a folder to store the attachment in" : "選擇一個資料夾來存放附件",
    "Import into calendar" : "匯入到日曆",
    "Download attachment" : "下載附件",
    "Save to Files" : "儲存至雲端檔案",
    "Attachments saved to Files" : "附件已儲存至「檔案」",
    "Error while saving attachments" : "儲存附件時發生錯誤",
    "View fewer attachments" : "檢視較少附件",
    "Choose a folder to store the attachments in" : "選擇一個資料夾來存放附件",
    "Save all to Files" : "全部儲存至檔案",
    "Download Zip" : "下載 Zip 壓縮檔",
    "_View {count} more attachment_::_View {count} more attachments_" : ["檢視另外 {count} 個附件"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此郵件使用 PGP 加密。安裝 Mailvelope 來解密。",
    "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入。",
    "Show images" : "顯示圖片",
    "Show images temporarily" : "暫時顯示圖片",
    "Always show images from {sender}" : "一律顯示來自 {sender} 的圖片",
    "Always show images from {domain}" : "一律顯示來自 {domain} 的圖片",
    "Message frame" : "郵件框",
    "Quoted text" : "引用文字",
    "Move" : "移動",
    "Moving" : "正在移動",
    "Moving thread" : "正在移動討論串",
    "Moving message" : "正在移動訊息",
    "This account cannot connect" : "此帳號無法連結",
    "Connection failed. Please verify your information and try again" : "連線失敗。請檢查您的資訊並再試一次",
    "Used quota: {quota}% ({limit})" : "已使用的配額：{quota}% ({limit})",
    "Used quota: {quota}%" : "已使用的配額：{quota}%",
    "Unable to create mailbox. The name likely contains invalid characters. Please try another name." : "無法建立信箱。該名稱可能包含無效字元。請嘗試其他名稱。",
    "Remove account" : "移除帳號",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 帳號與已快取的電子郵件將會從 Nextcloud 移除，但不會從您的電子郵件提供商移除。",
    "Remove {email}" : "移除 {email}",
    "Provisioned account is disabled" : "預先設定的帳號已停用",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "請使用密碼登入以啟用此帳號。目前的工作階段正在使用無密碼身份驗證，例如 SSO 或 WebAuthn。",
    "Show only subscribed folders" : "僅顯示已訂閱的資料夾",
    "Add folder" : "新增資料夾",
    "Folder name" : "資料夾名稱",
    "Saving" : "正在儲存",
    "Move up" : "向上移動",
    "Move down" : "向下移動",
    "Show all subscribed folders" : "顯示全部已訂閱的資料夾",
    "Show all folders" : "顯示所有收件匣",
    "Collapse folders" : "收合收件匣",
    "_{total} message_::_{total} messages_" : ["{total} 封郵件"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 中的 {unread} 未讀"],
    "Loading …" : "正在載入……",
    "All messages in mailbox will be deleted." : "郵箱中的所有訊息都將被刪除。",
    "Clear mailbox {name}" : "清除信箱 {name}",
    "Clear folder" : "清除資料夾",
    "The folder and all messages in it will be deleted." : "資料與其他中的所有訊息都會被刪除。",
    "Delete folder" : "刪除資料夾",
    "Delete folder {name}" : "刪除資料夾 {name}",
    "An error occurred, unable to rename the mailbox." : "遇到錯誤，無法重新命名信箱。",
    "Please wait 10 minutes before repairing again" : "請等待10分鐘再進行修復",
    "Mark all as read" : "全部標記為已讀",
    "Add subfolder" : "新增子資料夾",
    "Rename" : "重新命名",
    "Move folder" : "移動資料夾",
    "Repair folder" : "修復資料夾",
    "Clear cache" : "清除快取",
    "Clear locally cached data, in case there are issues with synchronization." : "如果遇到同步問題，請清除本機快取資料。",
    "Subscribed" : "已訂閱",
    "Sync in background" : "背景同步",
    "Delete all messages" : "刪除所有訊息",
    "Outbox" : "寄件匣",
    "Translate this message to {language}" : "將此訊息翻譯為{language}",
    "New message" : "新郵件",
    "Edit message" : "編輯訊息",
    "Draft" : "草稿",
    "Reply" : "回覆",
    "Message saved" : "訊息已儲存",
    "Failed to save message" : "儲存訊息失敗",
    "Failed to save draft" : "儲存草稿失敗",
    "attachment" : "附件",
    "attached" : "已附加",
    "No \"sent\" folder configured. Please pick one in the account settings." : "未設定「寄件備份」資料夾。請在帳號設定中選取。",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正試圖傳送郵件給「收件者」及／或「副本」中的許多人。請考慮使用「密件副本」來隱藏收件者地址。",
    "Your message has no subject. Do you want to send it anyway?" : "您的訊息沒有主旨。您還是想要寄送嗎？",
    "You mentioned an attachment. Did you forget to add it?" : "您提及了附件。您忘記新增了嗎？",
    "Message discarded" : "郵件已捨棄",
    "Could not discard message" : "無法捨棄郵件",
    "Maximize composer" : "最大化編輯器",
    "Show recipient details" : "顯示收件者詳細資訊",
    "Hide recipient details" : "隱藏收件者詳細資訊",
    "Minimize composer" : "最小化編輯器",
    "Error sending your message" : "傳送您的郵件時發生錯誤",
    "Retry" : "重試",
    "Warning sending your message" : "在傳送您的郵件時警告",
    "Send anyway" : "無論無何都要傳送",
    "Welcome to {productName} Mail" : "歡迎使用 {productName} Mail",
    "Start writing a message by clicking below or select an existing message to display its contents" : "點選下方開始編寫訊息，或選取現有訊息以顯示其內容",
    "Autoresponder off" : "自動回覆程式停用",
    "Autoresponder on" : "自動回覆程式啟用",
    "Autoresponder follows system settings" : "自動回應程式遵循系統設定",
    "The autoresponder follows your personal absence period settings." : "自動回應程式會依照您個人的缺席時段設定做出回應。",
    "Edit absence settings" : "編輯缺席設定",
    "First day" : "第一天",
    "Last day (optional)" : "最後一天（選擇性）",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} 將替換為您要回應的郵件的主旨",
    "Message" : "訊息",
    "Oh Snap!" : "喔喔！",
    "Save autoresponder" : "儲存自動回覆程式",
    "Could not open outbox" : "無法開啟寄件匣",
    "Pending or not sent messages will show up here" : "待處理或未傳送的郵件將會在此處顯示",
    "Could not copy to \"Sent\" folder" : "無法複製到「寄件備份」資料夾",
    "Mail server error" : "郵件伺服器錯誤",
    "Message could not be sent" : "無法傳送郵件",
    "Message deleted" : "郵件已刪除",
    "Copy to \"Sent\" Folder" : "複製到「寄件備份」資料夾",
    "Copy to Sent Folder" : "複製到「寄件備份」資料夾",
    "Phishing email" : "釣魚郵件",
    "This email might be a phishing attempt" : "這封電子郵件可能是釣魚郵件",
    "Hide suspicious links" : "隱藏可疑連結",
    "Show suspicious links" : "顯示可以連結",
    "link text" : "連結文字",
    "Copied email address to clipboard" : "將電子郵件地址複製到剪貼簿",
    "Could not copy email address to clipboard" : "無法複製電子郵件地址到剪貼簿",
    "Contacts with this address" : "有此地址的聯絡人",
    "Add to Contact" : "新增至聯絡人",
    "New Contact" : "新聯絡人",
    "Copy to clipboard" : "複製到剪貼簿",
    "Contact name …" : "聯絡人名稱……",
    "Add" : "新增",
    "Show less" : "顯示較少",
    "Show more" : "顯示更多",
    "Clear" : "清除",
    "Search in folder" : "在資料夾中搜尋",
    "Open search modal" : "開啟搜尋互動視窗",
    "Close" : "關閉",
    "Search parameters" : "搜尋參數",
    "Search subject" : "搜尋主旨",
    "Body" : "內文",
    "Search body" : "搜尋正文",
    "Date" : "日期",
    "Pick a start date" : "挑選開始日期",
    "Pick an end date" : "挑選結束日期",
    "Select senders" : "選取寄件者",
    "Select recipients" : "選取收件者",
    "Select CC recipients" : "選取副本收件者",
    "Select BCC recipients" : "選取密件副本收件者",
    "Tags" : "標籤",
    "Select tags" : "選取標籤",
    "Marked as" : "已標記為",
    "Has attachments" : "有附件",
    "Mentions me" : "提及我",
    "Has attachment" : "有附件",
    "To me" : "給我",
    "Enable mail body search" : "啟用郵件正文搜尋",
    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "Sieve 是為電子信箱編寫篩選器的強大語言。若您的電子郵件服務支援，您可以在郵件中管理篩選命令稿。使用自動回覆與篩選器也需要 Sieve。",
    "Enable sieve filter" : "啟用 sieve 篩選器",
    "Sieve host" : "過濾主機",
    "Sieve security" : "過濾安全",
    "Sieve Port" : "過濾連接埠",
    "Sieve credentials" : "過濾憑證",
    "IMAP credentials" : "IMAP 憑證",
    "Custom" : "自訂",
    "Sieve User" : "過濾使用者",
    "Sieve Password" : "過濾密碼",
    "Oh snap!" : "哎呀！",
    "Save sieve settings" : "儲存過濾設定",
    "The syntax seems to be incorrect:" : "語法似乎不正確：",
    "Save sieve script" : "儲存過濾指令稿",
    "Signature …" : "簽名……",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "您的簽名檔大於 2 MB。這可能會影響編輯器的效能。",
    "Save signature" : "儲存簽名",
    "Place signature above quoted text" : "將簽名置於引用文字上方",
    "Message source" : "郵件原始碼",
    "An error occurred, unable to rename the tag." : "發生錯誤，無法重新命名標籤。",
    "Edit name or color" : "編輯名稱或顏色",
    "Saving new tag name …" : "正在儲存新標籤名稱……",
    "Delete tag" : "刪除標籤",
    "Set tag" : "設定標籤",
    "Unset tag" : "取消設定標籤",
    "Tag name is a hidden system tag" : "標籤名稱為隱藏的系統標籤",
    "Tag already exists" : "標籤已經存在",
    "Tag name cannot be empty" : "標籤名稱不可為空白",
    "An error occurred, unable to create the tag." : "遇到錯誤，無法建立標籤。",
    "Add default tags" : "新增預設標籤",
    "Add tag" : "新增標籤",
    "Saving tag …" : "正在儲存標籤……",
    "Task created" : "已建立工作",
    "Could not create task" : "無法建立工作",
    "No calendars with task list support" : "沒有支援工作清單的日曆",
    "Summarizing thread failed." : "總結討論串失敗。",
    "Could not load your message thread" : "無法載入您的郵件串",
    "The thread doesn't exist or has been deleted" : "討論串不存在或已被刪除",
    "Email was not able to be opened" : "無法開啟電子郵件",
    "Print" : "列印",
    "Could not print message" : "無法列印訊息",
    "Loading thread" : "正在載入討論串",
    "Not found" : "找不到",
    "Encrypted & verified " : "加密與驗證",
    "Signature verified" : "簽章已驗證",
    "Signature unverified " : "簽章未驗證",
    "This message was encrypted by the sender before it was sent." : "此訊息在傳送前已由寄件人加密。",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "此訊息包含了已驗證的數位 S/MIME 簽章。訊息自傳送後未變更。",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "此訊息包含了未驗證的 S/MIME 簽章。訊息在傳送後可能已被變更，或是簽章者的證書不受信任。",
    "Reply all" : "回覆所有人",
    "Unsubscribe request sent" : "取消訂閱請求已傳送",
    "Could not unsubscribe from mailing list" : "無法從郵件清單取消訂閱",
    "Please wait for the message to load" : "請等待訊息載入",
    "Disable reminder" : "停用提醒",
    "Unsubscribe" : "取消訂閱",
    "Reply to sender only" : "僅回覆寄件者",
    "Mark as unfavorite" : "取消標記為我的最愛",
    "Mark as favorite" : "標記為我的最愛",
    "To:" : "至：",
    "Unsubscribe via link" : "透過連結取消訂閱",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "取消訂閱將停止來自郵件清單 {sender} 的所有訊息",
    "Send unsubscribe email" : "傳送取消訂閱電子郵件",
    "Unsubscribe via email" : "透過電子郵件取消訂閱",
    "{name} Assistant" : "{name} 小幫手",
    "Thread summary" : "討論串摘要",
    "Go to latest message" : "到最新的郵件",
    "Newest message" : "最新的訊息",
    "This summary is AI generated and may contain mistakes." : "此摘要為人工智慧產生，可能會出錯。",
    "Please select languages to translate to and from" : "請選取要翻譯的來源與目標語言",
    "The message could not be translated" : "無法翻譯訊息",
    "Translation copied to clipboard" : "翻譯已複製到剪貼簿",
    "Translation could not be copied" : "無法複製翻譯",
    "Translate message" : "翻譯訊息",
    "Source language to translate from" : "要翻譯的來源語言",
    "Translate from" : "翻譯從",
    "Target language to translate into" : "要翻譯至的目標語言",
    "Translate to" : "翻譯至",
    "Translating" : "正在翻譯",
    "This translation is generated using AI and may contain inaccuracies" : "此翻譯使用人工智慧產生，可能不準確",
    "Copy translated text" : "複製已翻譯的文字",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "將該欄位留空或設定其為 0 來停用垃圾保留。僅處理啟用垃圾保留後的郵件。",
    "Could not remove trusted sender {sender}" : "無法移除受信任的寄件者 {sender}",
    "No senders are trusted at the moment." : "目前沒有寄件者受到信任。",
    "Untitled event" : "未命名行程",
    "(organizer)" : "（主辦人）",
    "Import into {calendar}" : "已匯入至 {calendar}",
    "Event imported into {calendar}" : "活動已匯入至 {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "航班 {flightNr} 從 {depAirport} 至 {arrAirport}",
    "Airplane" : "飛機",
    "Reservation {id}" : "預訂 {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 從 {depStation} 至 {arrStation}",
    "Train from {depStation} to {arrStation}" : "從 {depStation} 至 {arrStation} 的火車",
    "Train" : "火車",
    "Mark message as" : "標記訊息為",
    "Add flag" : "新增旗標",
    "Move into folder" : "移動進資料夾",
    "Stop" : "停止",
    "Delete action" : "刪除動作",
    "Answered" : "回應",
    "Deleted" : "已刪除",
    "Flagged" : "已標記",
    "Seen" : "已看過",
    "Enter flag" : "輸入旗標",
    "Stop ends all processing" : "停止將會結束所有處理",
    "Sender" : "寄件者",
    "Recipient" : "收件人",
    "Create a new mail filter" : "建立新的郵件篩選器",
    "Choose the headers you want to use to create your filter. In the next step, you will be able to refine the filter conditions and specify the actions to be taken on messages that match your criteria." : "選擇您要用於建立篩選器的標頭。在下一步中，您可以細化篩選條件，並指定對符合條件的郵件要執行的動作。",
    "Delete filter" : "刪除過濾條件",
    "Delete mail filter {filterName}?" : "刪除郵件篩選器 {filterName}？",
    "Are you sure to delete the mail filter?" : "您確定要刪除郵件篩選器嗎？",
    "New filter" : "新篩選器",
    "Filter saved" : "已儲存篩選器",
    "Could not save filter" : "無法儲存篩選器",
    "Filter deleted" : "篩選器已刪除",
    "Could not delete filter" : "無法刪除篩選器",
    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "控制您混亂的電子郵件。篩選器會協助您排定優先順序並消除雜訊。",
    "Hang tight while the filters load" : "請稍候，正在載入篩選條件",
    "Filter is active" : "篩選器作用中",
    "Filter is not active" : "篩選器未啟動",
    "If all the conditions are met, the actions will be performed" : "若滿足所有條件，將會執行動作",
    "If any of the conditions are met, the actions will be performed" : "若滿足任何條件，將會執行動作",
    "Help" : "說明",
    "contains" : "包含",
    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "子字串符合。如果提供的值包含在欄位中，該欄位就會相符。舉例來說，「report」會符合「port」。",
    "matches" : "符合",
    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "使用萬用字元的模式符合。「*」代表任何數量的字元（包含沒有），而「?」則代表正好一個字元。舉例來說「*report」將會符合「Business report 2024」。",
    "Enter subject" : "輸入主旨",
    "Enter sender" : "輸入寄件者",
    "Enter recipient" : "輸入收件者",
    "is exactly" : "剛好是",
    "Conditions" : "條件",
    "Add condition" : "新增條件",
    "Actions" : "動作",
    "Add action" : "新增動作",
    "Priority" : "優先",
    "Enable filter" : "啟用篩選器",
    "Tag" : "標籤",
    "delete" : "刪除",
    "Edit quick action" : "編輯快速動作",
    "Add quick action" : "新增快速動作",
    "Quick action deleted" : "已刪除快速動作",
    "Failed to delete quick action" : "刪除快速動作失敗",
    "Failed to update quick action" : "更新快速動作失敗",
    "Failed to update step in quick action" : "在快速動作中更新步驟失敗",
    "Quick action updated" : "已更新快速動作",
    "Failed to create quick action" : "建立快速動作失敗",
    "Failed to add steps to quick action" : "新增步驟至快速動作失敗",
    "Quick action created" : "已建立快速動作",
    "Failed to delete action step" : "刪除動作步驟失敗",
    "No quick actions yet." : "尚無快速動作。",
    "Edit" : "編輯",
    "Quick action name" : "快速動作名稱",
    "Do the following actions" : "執行以下動作",
    "Add another action" : "新增其他動作",
    "Successfully updated config for \"{domain}\"" : "成功為「{domain}」更新設定",
    "Error saving config" : "儲存設定時發生錯誤",
    "Saved config for \"{domain}\"" : "已為「{domain}」儲存設定",
    "Could not save provisioning setting" : "無法儲存預備設定",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["成功設定 {count} 個帳號。"],
    "There was an error when provisioning accounts." : "設定帳號時發生錯誤。",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "成功刪除並取消設定了「{domain}」的帳號",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "刪除並取消設定「{domain}」的帳號時發生錯誤",
    "Could not save default classification setting" : "無法儲存預設分類設定",
    "Mail app" : "郵件應用程式",
    "The mail app allows users to read mails on their IMAP accounts." : "郵件應用程式允許使用者閱讀在他們 IMAP 帳號上的郵件。",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "您可以在此找到全站台的設定。在應用程式本身（左下角）可以找到使用者設定。",
    "Account provisioning" : "帳號設定",
    "A provisioning configuration will provision all accounts with a matching email address." : "預備設定將會為所有符合特定電子郵件地址的帳號提供。",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "在預備網域欄位中使用萬用字元 (*) 將會建立適用於所有使用者的設定，前提是這些使用者與其他設定不相符。",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "預備機制將優先於特定的網域設定，最後才是萬用字元網域設定。",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "如果使用者已被提供另一個設定後，又發現新的符合的設定，那麼新設定優先，使用者將會重新使用該設定。",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "每個網域只能有一個設定，且僅能有一個萬用字元網域設定。",
    "These settings can be used in conjunction with each other." : "這些設定可以相互結合使用。",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "如果您只想為所有使用者預備一個網域，請使用萬用字元 (*)。",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "此設定僅在您組織的 Nextcloud 與郵件伺服器使用相同的使用者後端時才有用。",
    "Provisioning Configurations" : "帳號設定",
    "Add new config" : "加入新設定",
    "Provision all accounts" : "預備所有帳號",
    "Allow additional mail accounts" : "允許其他郵件帳號",
    "Allow additional Mail accounts from User Settings" : "從使用者設定允許其他郵件帳號",
    "Enable text processing through LLMs" : "透過大型語言模型啟用文字處理",
    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Mail 應用程式可以使用已設定的大型語言模型處理使用者資料，並提供討論串摘要、智慧型回覆與活動議程等協助功能。",
    "Enable LLM processing" : "啟用大型語言模型處理",
    "Enable classification by importance by default" : "預設啟用按重要性分類",
    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "郵件應用程式可以使用機器學習來根據重要性將收到的電子郵件進行分類。此功能預設為啟用狀態，但可以在此處設定為預設停用。個別使用者仍然可以為其帳號啟用該功能。",
    "Enable classification of important mails by default" : "預設啟用重要郵件分類",
    "Anti Spam Service" : "反垃圾郵件服務",
    "You can set up an anti spam service email address here." : "您可以在此設定反垃圾郵件服務的電子郵件地址。",
    "Any email that is marked as spam will be sent to the anti spam service." : "任何被標記為垃圾郵件的電子郵件都將會被傳送至反垃圾郵件服務。",
    "Gmail integration" : "Gmail 整合",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail 讓使用者可以透過 IMAP 存取他們的電子郵件。出於安全理由，僅能使用 OAuth 2.0 連線或使用雙重驗證與應用程式密碼的 Google 帳號才能進行此存取。",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "您必須在 Google Cloud 主控台中的「Web 應用程式」註冊一個新的客戶端 ID。新增 URL {url} 作為授權重新導向 URI。",
    "Microsoft integration" : "Microsoft 整合",
    "Microsoft requires you to access your emails via IMAP using OAuth 2.0 authentication. To do this, you need to register an app with Microsoft Entra ID, formerly known as Microsoft Azure Active Directory." : "Microsoft 要求您使用 OAuth 2.0 驗證透過 IMAP 存取電子郵件。要做到這一點，您必須在 Microsoft Entra ID（以前稱為 Microsoft Azure Active Directory）註冊應用程式。",
    "Redirect URI" : "重新導向 URI",
    "For more details, please click here to open our documentation." : "請點選此處開啟我們的文件以了解更多資訊。",
    "User Interface Preference Defaults" : "使用者介面偏好設定預設值",
    "These settings are used to pre-configure the user interface preferences they can be overridden by the user in the mail settings" : "這些設定用來預先設定使用者介面偏好設定，使用者可以在郵件設定中覆寫這些偏好設定",
    "Message View Mode" : "訊息檢視模式",
    "Show only the selected message" : "僅顯示選定的訊息",
    "Successfully set up anti spam email addresses" : "成功設定了反垃圾郵件電子郵件地址",
    "Error saving anti spam email addresses" : "儲存反垃圾郵件電子郵件地址時發生錯誤",
    "Successfully deleted anti spam reporting email" : "成功刪除了反垃圾電子郵件回報電子郵件",
    "Error deleting anti spam reporting email" : "刪除反垃圾郵件回報電子郵件時發生錯誤",
    "Anti Spam" : "反垃圾郵件",
    "Add the email address of your anti spam report service here." : "在此新增您的反垃圾郵件回報服務電子郵件地址。",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "使用此設定時，當使用者點擊「標記為垃圾郵件」時，會向垃圾郵件回報伺服器傳送回報電子郵件。",
    "The original message will be attached as a \"message/rfc822\" attachment." : "原始訊息將會以「message/rfc822」作為附件。",
    "\"Mark as Spam\" Email Address" : "「標記為垃圾郵件」電子郵件地址",
    "\"Mark Not Junk\" Email Address" : "「標記為非垃圾郵件」電子郵件地址",
    "Reset" : "重設",
    "Google integration configured" : "已設定 Google 整合",
    "Could not configure Google integration" : "無法設定 Google 整合",
    "Google integration unlinked" : "Google 整合已取消連結",
    "Could not unlink Google integration" : "無法取消連結 Google 整合",
    "Client ID" : "客戶端 ID",
    "Client secret" : "客戶端密碼",
    "Unlink" : "取消連結",
    "Microsoft integration configured" : "已設定 Microsoft 整合",
    "Could not configure Microsoft integration" : "無法設定 Microsoft 整合",
    "Microsoft integration unlinked" : "取消連結 Microsoft 整合",
    "Could not unlink Microsoft integration" : "無法取消連結 Microsoft 整合",
    "Tenant ID (optional)" : "租戶 ID（選擇性）",
    "Domain Match: {provisioningDomain}" : "網域符合：{provisioningDomain}",
    "Email: {email}" : "電子郵件：{email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}:{port}（{ssl} 加密）",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP：{user} 在 {host}:{port}（{ssl} 加密）",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "過濾：{user} 在 {host}:{port}（{ssl} 加密）",
    "Configuration for \"{provisioningDomain}\"" : "「{provisioningDomain}」的設定",
    "Provisioning domain" : "預備設定網域",
    "Email address template" : "電子郵件地址範本",
    "IMAP" : "IMAP",
    "User" : "使用者",
    "Host" : "主機",
    "Port" : "連接埠",
    "SMTP" : "SMTP",
    "Master password" : "主控密碼",
    "Use master password" : "使用主控密碼",
    "Sieve" : "過濾",
    "Enable sieve integration" : "啟用過濾整合",
    "LDAP aliases integration" : "LDAP 別名整合",
    "Enable LDAP aliases integration" : "啟用 LDAP 別名整合",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP 別名整合會從設定好的 LDAP 目錄讀取屬性以提供電子郵件別名。",
    "LDAP attribute for aliases" : "別名的 LDAP 屬性",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "用於設定電子郵件別名的多重值屬性。為每個值建立一個別名。刪除存在於 Nextcloud 但不在 LDAP 目錄中的別名。",
    "Save Config" : "儲存設定",
    "Unprovision & Delete Config" : "取消設定與刪除設定",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% 與 %EMAIL% 將以使用者的 UID 與電子郵件取代",
    "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立帳號：",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "提供的 PKCS #12 憑證必須包含至少一個憑證與一個私鑰。",
    "Failed to import the certificate. Please check the password." : "匯入憑證失敗。請檢查密碼。",
    "Certificate imported successfully" : "成功匯出憑證",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "無法匯入憑證。請確保私鑰與憑證相符，且不受密語保護。",
    "Failed to import the certificate" : "匯入憑證失敗",
    "S/MIME certificates" : "S/MIME 憑證",
    "Certificate name" : "憑證名稱",
    "E-mail address" : "電子郵件地址",
    "Valid until" : "到期日",
    "Delete certificate" : "刪除憑證",
    "No certificate imported yet" : "尚未匯入憑證",
    "Import certificate" : "匯入憑證",
    "Import S/MIME certificate" : "匯入 S/MIME 憑證",
    "PKCS #12 Certificate" : "PKCS #12 憑證",
    "PEM Certificate" : "PEM 憑證",
    "Certificate" : "憑證",
    "Private key (optional)" : "私鑰（選擇性）",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "僅當您打算使用此憑證傳送簽署與加密的電子郵件時才需要私鑰。",
    "Submit" : "提交",
    "No text blocks available" : "無可用的文字區塊",
    "Text block deleted" : "已刪除文字區塊",
    "Failed to delete text block" : "刪除文字區塊失敗",
    "Text block shared with {sharee}" : "已與 {sharee} 分享文字區塊",
    "Failed to share text block with {sharee}" : "無法與 {sharee} 分享文字區塊",
    "Share deleted for {name}" : "{name} 的分享已被刪除",
    "Failed to delete share with {name}" : "無法刪除與 {name} 的分享",
    "Guest" : "訪客",
    "Group" : "群組",
    "Failed to save text block" : "儲存文字區塊失敗",
    "Shared" : "已分享",
    "Edit {title}" : "編輯 {title}",
    "Delete {title}" : "刪除 {title}",
    "Edit text block" : "編輯文字區塊",
    "Shares" : "分享",
    "Search for users or groups" : "搜尋使用者或群組",
    "Choose a text block to insert at the cursor" : "選擇文字區塊以在游標處插入",
    "Insert" : "插入",
    "Insert text block" : "插入文字區塊",
    "Account connected" : "已連結帳號",
    "You can close this window" : "您可以關閉此視窗",
    "Connect your mail account" : "連結您的郵件帳號",
    "To add a mail account, please contact your administrator." : "要新增郵件帳號，請聯絡您的管理員。",
    "All" : "全部",
    "Drafts" : "草稿",
    "Priority inbox" : "優先收件匣",
    "All inboxes" : "所有收件匣",
    "Inbox" : "收件匣",
    "Junk" : "垃圾郵件",
    "Sent" : "寄件備份",
    "Trash" : "回收筒",
    "Connect OAUTH2 account" : "連結 OAUTH2 帳號",
    "Error while sharing file" : "分享檔案時發生錯誤",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n 則新信件\n來自 {from}"],
    "Nextcloud Mail" : "Nextcloud 郵件",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "正在編寫一則訊息。若您繼續，所有未儲存的變更將會遺失！",
    "Discard changes" : "放棄變更",
    "Discard unsaved changes" : "放棄未儲存變更",
    "Keep editing message" : "保留編輯中的訊息",
    "(All or part of this reply was generated by AI)" : "（此回覆的全部或部分內容由人工智慧產生）",
    "Attachments were not copied. Please add them manually." : "未複製附件。請手動新增它們。",
    "Could not create snooze mailbox" : "無法建立暫停郵件信箱",
    "Sorry, the message could not be loaded. The draft may no longer exist. Please refresh the page and try again." : "抱歉，訊息無法載入。草稿可能已不存在。請重新整理頁面並重試。",
    "Sending message…" : "正在傳送訊息……",
    "Message sent" : "已傳送郵件",
    "Could not send message" : "無法傳送郵件",
    "Message copied to \"Sent\" folder" : "訊息已複製到「寄件備份」資料夾",
    "Could not copy message to \"Sent\" folder" : "無法複製訊息至「寄件備份」資料夾",
    "Could not load {tag}{name}{endtag}" : "無法載入 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "載入 {tag}{name}{endtag} 時出現問題",
    "Could not load your message" : "無法載入您的信件",
    "Could not load the desired message" : "無法載入所選的信件",
    "Could not load the message" : "無法載入信件",
    "Error loading message" : "載入信件錯誤",
    "Determine importance using machine learning" : "使用機器學習判斷重要程度",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "郵件將會以您與其互動或標記為重要的郵件為基礎來自動標記重要郵件。ㄧ開始，您可以能必須手動教導系統哪些是重要郵件，然後它就會與時俱進。",
    "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "您傳送的訊息若未在幾天內收到回覆，將在此處顯示。",
    "Mark all messages of this folder as read" : "將此資料夾中所有的訊息都標記為已讀",
    "Last 7 days" : "過去7天",
    "From me" : "來自我"
},
"nplurals=1; plural=0;");
